==> 0.4.0.tar.gz: lib/fc_sort_button.dart <==
import 'package:fc_components/fc_button.dart';
import 'package:fc_components/util/adapt.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

/// 排序方式
enum FcSortOrder {
  /// 正序排序
  asc,
  /// 倒序排序
  desc
}

typedef Callback<T> = void Function(T value);

class FcSortButton extends StatelessWidget {
  const FcSortButton({
    Key? key, 
    required this.onPressed,
    this.text = '',
    this.hasSort = true,
    this.highlight = false,
    this.order
  }) : super(key: key);

  final Callback<FcSortOrder?> onPressed;
  final String text;
  final bool hasSort;
  final FcSortOrder? order;
  final bool highlight;

  /// 正序排序
  Widget triangleTop() {
    Color? color = const Color(0xFF666666);
    if (highlight && order == FcSortOrder.asc) {
      color = Colors.white;
    } else if (highlight) {
      color = Colors.white.withOpacity(0.55);
    }

    return ImageIcon(
      const AssetImage('images/triangle_top.png'),
      size: Adapt.px(15),
      color: color
    );
  }

  /// 倒序排序
  Widget triangleBottom() {
    Color? color = const Color(0xFF666666);
    if (highlight && order == FcSortOrder.desc) {
      color = Colors.white;
    } else if (highlight) {
      color = Colors.white.withOpacity(0.55);
    }

    return ImageIcon(
      const AssetImage('images/triangle_bottom.png'),
      size: Adapt.px(15),
      color: color
    );
  }

  List<Widget> inside() {
    List<Widget> inside = [
      Text(text, style: TextStyle(color: highlight ? null : const Color(0xFF666666)))
    ];

    if (hasSort) {
      inside.add(Padding(
        padding: EdgeInsets.only(left: Adapt.px(5)),
        child: Column(
          children: [
            triangleTop(),
            triangleBottom()
          ],
        ),
      ));
    }
    return inside;
  }

  @override
  Widget build(BuildContext context) {
    return FcButton(
      radius: Adapt.px(30),
      color: highlight ? null : Colors.white,
      size: FcButtonSize.small,
      customSize: Size(Adapt.px(100), Adapt.px(58)),
      onPressed: () {
        FcSortOrder? sortOrder;
        if (hasSort) {
          if (!highlight) {
            sortOrder = FcSortOrder.asc;
          } else {
            sortOrder = order == FcSortOrder.desc ? FcSortOrder.asc : FcSortOrder.desc;
          }
        }
        onPressed(sortOrder);
      },
      child: Row(
        children: inside(),
      )
    );
  }
}

==> 0.5.0.tar.gz: lib/fc_sort_button.dart <==
import 'package:fc_components/fc_button.dart';
import 'package:fc_components/util/adapt.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

/// 排序方式
enum FcSortOrder {
  /// 正序排序
  asc,
  /// 倒序排序
  desc
}

typedef Callback<T> = void Function(T value);

class FcSortButton extends StatelessWidget {
  const FcSortButton({
    Key? key, 
    required this.onPressed,
    this.text = '',
    this.hasSort = true,
    this.highlight = false,
    this.order
  }) : super(key: key);

  final Callback<FcSortOrder?> onPressed;
  final String text;
  final bool hasSort;
  final FcSortOrder? order;
  final bool highlight;

  /// 正序排序
  Widget triangleTop() {
    Color? color = const Color(0xFF666666);
    if (highlight && order == FcSortOrder.asc) {
      color = Colors.white;
    } else if (highlight) {
      color = Colors.white.withOpacity(0.55);
    }

    return ImageIcon(
      const AssetImage('images/triangle_top.png', package: "fc_components"),
      size: Adapt.px(15),
      color: color
    );
  }

  /// 倒序排序
  Widget triangleBottom() {
    Color? color = const Color(0xFF666666);
    if (highlight && order == FcSortOrder.desc) {
      color = Colors.white;
    } else if (highlight) {
      color = Colors.white.withOpacity(0.55);
    }

    return ImageIcon(
      const AssetImage('images/triangle_bottom.png', package: "fc_components"),
      size: Adapt.px(15),
      color: color
    );
  }

  List<Widget> inside() {
    List<Widget> inside = [
      Text(text, style: TextStyle(color: highlight ? null : const Color(0xFF666666)))
    ];

    if (hasSort) {
      inside.add(Padding(
        padding: EdgeInsets.only(left: Adapt.px(5)),
        child: Column(
          children: [
            triangleTop(),
            triangleBottom()
          ],
        ),
      ));
    }
    return inside;
  }

  @override
  Widget build(BuildContext context) {
    return FcButton(
      radius: Adapt.px(30),
      color: highlight ? null : Colors.white,
      size: FcButtonSize.small,
      customSize: Size(Adapt.px(100), Adapt.px(58)),
      onPressed: () {
        FcSortOrder? sortOrder;
        if (hasSort) {
          if (!highlight) {
            sortOrder = FcSortOrder.asc;
          } else {
            sortOrder = order == FcSortOrder.desc ? FcSortOrder.asc : FcSortOrder.desc;
          }
        }
        onPressed(sortOrder);
      },
      child: Row(
        children: inside(),
      )
    );
  }
}
